package FFFF::Session;
# -------------------------------------------------------------------------
# FFFF::Session
#
# - 4F åե
#
#
# -------------------------------------------------------------------------
use strict;

use vars qw(@ISA);
@ISA = qw(Base::Session::Cookie); 
use Base::Session::Cookie;

sub new {
	my $class = shift;
	my %option = @_;

	my $self = $class->SUPER::new(

		#
		# Apache::Session  Store
		#
		STORE          => 'File',


		#
		# Apache::Session Ϥѥ᡼
		#
		SESSION_OPTION => {
			Directory     => $option{SESSION_DIR},
			LockDirectory => $option{SESSION_DIR},
		},


		#
		# åϥåɻߤΤ̩
		#
		DIGEST_KEY => 'BALBFTB2JEKLF8O6SX10TVVA1' . $ENV{HTTP_USER_AGENT},


		#
		# åͭ֡á
		#
		EXPIRE => 3600 * 24,

		#
		# å¸뤿Υ
		#
		COOKIE_KEY => $option{COOKIE_KEY},
	);

	return $self;
}

1;
